* mln/core/alias/point1d.hh (mln::point1df): New.
Adjust documentation.
---
milena/ChangeLog | 7 +++++++
milena/mln/core/alias/point1d.hh | 13 ++++++++-----
2 files changed, 15 insertions(+), 5 deletions(-)
diff --git a/milena/ChangeLog b/milena/ChangeLog
index b1a2676..1bea379 100644
--- a/milena/ChangeLog
+++ b/milena/ChangeLog
@@ -1,3 +1,10 @@
+2009-05-18 Roland Levillain <roland(a)lrde.epita.fr>
+
+ Add a floating-point 1-dimensional point type.
+
+ * mln/core/alias/point1d.hh (mln::point1df): New.
+ Adjust documentation.
+
2009-05-18 Guillaume Sadegh <sadegh(a)lrde.epita.fr>
New tests for browsing on graphs.
diff --git a/milena/mln/core/alias/point1d.hh b/milena/mln/core/alias/point1d.hh
index ac13d44..6fd8477 100644
--- a/milena/mln/core/alias/point1d.hh
+++ b/milena/mln/core/alias/point1d.hh
@@ -31,8 +31,8 @@
/// \file mln/core/alias/point1d.hh
///
/// Definition of the mln::point1d alias and of its construction
/// routine.
# include <mln/core/point.hh>
// For site_const_impl and site_mutable_impl.
@@ -43,11 +43,14 @@
namespace mln
{
- /// Type alias for a point defined on the 1D square grid with
- /// integer coordinates.
- //
+ /// Type alias for a point defined on the 1D ruler with integer
+ /// coordinates.
typedef point<grid::tick, def::coord> point1d;
+ /// Type alias for a point defined on the 1D ruler with
+ /// floating-point coordinates.
+ typedef point<grid::tick, def::coordf> point1df;
+
namespace internal
{
@@ -31,8 +31,8 @@
/// \file mln/core/alias/point1d.hh
///
-/// Definition of the mln::point1d alias and of its construction
-/// routine.
+/// Definition of the mln::point1d and mln::point1df aliases and of
+/// their construction routines.
# include <mln/core/point.hh>
// For site_const_impl and site_mutable_impl.
--
1.6.2.4